@@ -1,7 +1,7 @@
 package App::AcmeCpanlists;
 
-our $DATE = '2015-10-23'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-10-29'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -299,6 +299,95 @@ sub view_list {
         "cmdline.pager"=>"pod2man | man -l -"}];
 }
 
+sub _is_false { defined($_[0]) && !$_[0] }
+
+$SPEC{list_entries} = {
+    v => 1.1,
+    summary => 'List entries of a CPAN list',
+    args_rels => {
+        %rels_filtering,
+    },
+    args => {
+        %args_filtering,
+        %arg_query,
+        %arg_detail,
+        related => {
+            summary => 'Filter based on whether entry is in related',
+            'summary.alt.bool.yes' => 'Only list related entries',
+            'summary.alt.bool.not' => 'Do not list related entries',
+            schema => 'bool',
+        },
+        alternate => {
+            summary => 'Filter based on whether entry is in alternate',
+            'summary.alt.bool.yes' => 'Only list alternate entries',
+            'summary.alt.bool.not' => 'Do not list alternate entries',
+            schema => 'bool',
+        },
+    },
+};
+sub list_entries {
+    require Pod::From::Acme::CPANLists;
+    no strict 'refs';
+
+    my %args = @_;
+
+    my $res = get_list(%args);
+    return $res unless $res->[0] == 200;
+
+    my $type = $res->[3]{'func.type'};
+    my $list = $res->[2];
+
+    my @cols;
+    if ($args{detail}) {
+        @cols = ($type, qw/summary rating/);
+    } else {
+        @cols = ($type);
+    }
+
+    my %seen;
+    my @rows;
+    for my $e (@{ $list->{entries} }) {
+        my $n = $e->{$type};
+        unless ($args{related} || $args{alternate}) {
+            unless ($seen{$n}++) {
+                push @rows, {
+                    $type => $n,
+                    summary=>$e->{summary},
+                    rating=>$e->{rating},
+                };
+            }
+        }
+        for my $n (@{ $e->{"related_${type}s"} // [] }) {
+            if ($args{related}) {
+                unless ($seen{$n}++) {
+                    push @rows, {
+                        $type => $n,
+                        summary=>$e->{summary},
+                        related=>1,
+                    };
+                }
+            }
+        }
+        for my $n (@{ $e->{"alternate_${type}s"} // [] }) {
+            if ($args{alternate}) {
+                unless ($seen{$n}++) {
+                    push @rows, {
+                        $type => $n,
+                        summary=>$e->{summary},
+                        alternate=>1,
+                    };
+                }
+            }
+        }
+    }
+
+    unless ($args{detail}) {
+        @rows = map {$_->{$type}} @rows;
+    }
+
+    [200, "OK", \@rows, {'table.fields' => \@cols}];
+}
+
 1;
 # ABSTRACT: The Acme::CPANLists CLI (backend module)
 
@@ -314,7 +403,7 @@ App::AcmeCpanlists - The Acme::CPANLists CLI (backend module)
 
 =head1 VERSION
 
-This document describes version 0.04 of App::AcmeCpanlists (from Perl distribution App-AcmeCpanlists), released on 2015-10-23.
+This document describes version 0.05 of App::AcmeCpanlists (from Perl distribution App-AcmeCpanlists), released on 2015-10-29.
 
 =head1 SYNOPSIS
 
@@ -357,6 +446,50 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 list_entries(%args) -> [status, msg, result, meta]
+
+List entries of a CPAN list.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<alternate> => I<bool>
+
+Filter based on whether entry is in alternate.
+
+=item * B<detail> => I<bool>
+
+=item * B<mentions_author> => I<str>
+
+=item * B<mentions_module> => I<str>
+
+=item * B<module> => I<str>
+
+=item * B<query>* => I<str>
+
+=item * B<related> => I<bool>
+
+Filter based on whether entry is in related.
+
+=item * B<type> => I<str>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 list_lists(%args) -> [status, msg, result, meta]
 
 List CPAN lists.
